@@ -63,6 +63,7 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	GtkWidget    *label;
 	GtkWidget    *image;
 	GtkWidget    *hbox;
+	GtkWidget    *content_area;
 	va_list       args;
 	const gchar  *text;
 	int           response_id;
@@ -75,10 +76,12 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 
 	dialog = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 8);
+	gtk_container_set_border_width (GTK_CONTAINER (content_area), 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 8);
 
 	/* Add label and image */
 
@@ -120,7 +123,7 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	gtk_box_pack_start (GTK_BOX (hbox), label,
 			    TRUE, TRUE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    hbox,
 			    FALSE, FALSE, 0);
 
@@ -156,16 +159,11 @@ create_button (const char *stock_id,
 	       const char *text)
 {
 	GtkWidget    *button;
-	GtkWidget    *hbox;
 	GtkWidget    *image;
-	GtkWidget    *label;
-	GtkWidget    *align;
 	const char   *label_text;
 	gboolean      text_is_stock;
 	GtkStockItem  stock_item;
 
-	button = gtk_button_new ();
-
 	if (gtk_stock_lookup (text, &stock_item)) {
 		label_text = stock_item.label;
 		text_is_stock = TRUE;
@@ -178,19 +176,12 @@ create_button (const char *stock_id,
 		image = gtk_image_new_from_stock (text, GTK_ICON_SIZE_BUTTON);
 	else
 		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-	label = gtk_label_new_with_mnemonic (label_text);
-	hbox = gtk_hbox_new (FALSE, 2);
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	button = gtk_button_new_with_mnemonic (label_text);
+	gtk_button_set_image (GTK_BUTTON (button), image);
 
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
+	gtk_widget_set_can_default (button, TRUE);
 
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-
-	gtk_widget_show_all (button);
+	gtk_widget_show (button);
 
 	return button;
 }
@@ -213,6 +204,7 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 	GtkWidget    *vbox;
 	GtkWidget    *entry;
 	GtkWidget    *button;
+	GtkWidget    *content_area;
 	char         *stock_id;
 	char         *result;
 
@@ -220,10 +212,12 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 
 	dialog = gtk_dialog_new_with_buttons (title, parent, flags, NULL);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 8);
+	gtk_container_set_border_width (GTK_CONTAINER (content_area), 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 8);
 
 	/* Add label and image */
 
@@ -257,7 +251,7 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 	gtk_box_pack_start (GTK_BOX (vbox), entry,
 			    FALSE, FALSE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    hbox,
 			    FALSE, FALSE, 0);
 
@@ -304,15 +298,18 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	GtkWidget    *image;
 	GtkWidget    *hbox;
 	GtkWidget    *button;
+	GtkWidget    *content_area;
 	char         *stock_id = GTK_STOCK_DIALOG_WARNING;
 
 	d = gtk_dialog_new_with_buttons ("", parent, flags, NULL);
 	gtk_window_set_resizable (GTK_WINDOW (d), FALSE);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (d));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (d), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (d), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (d)->vbox), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (d)->vbox), 8);
+	gtk_container_set_border_width (GTK_CONTAINER (content_area), 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 8);
 
 	/* Add label and image */
 
@@ -332,7 +329,7 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	gtk_box_pack_start (GTK_BOX (hbox), label,
 			    TRUE, TRUE, 0);
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (d)->vbox),
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    hbox,
 			    FALSE, FALSE, 0);
 
@@ -376,6 +373,7 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 	GtkWidget     *text_view;
 	GtkWidget     *scrolled = NULL;
 	GtkWidget     *expander;
+	GtkWidget     *content_area;
 	GtkTextBuffer *text_buf;
 	GtkTextIter    iter;
 	char          *stock_id;
@@ -394,10 +392,12 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 8);
+	gtk_container_set_border_width (GTK_CONTAINER (content_area), 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 8);
 
 	gtk_widget_set_size_request (dialog, 500, -1);
 
@@ -438,7 +438,7 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 
 		expander = gtk_expander_new_with_mnemonic (_("Command _Line Output"));
 		gtk_expander_set_expanded (GTK_EXPANDER (expander), secondary_text == NULL);
-		
+
 		/* Add text */
 
 		scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -488,7 +488,7 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 		gtk_box_pack_start (GTK_BOX (vbox), expander, TRUE, TRUE, 0);
 	}
 
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    vbox,
 			    FALSE, FALSE, 0);
 	gtk_widget_show_all (vbox);
@@ -688,13 +688,13 @@ get_file_icon_pixbuf (GFileIcon *icon,
 	GFile     *file;
 	char      *filename;
 	GdkPixbuf *pixbuf;
-	
+
 	file = g_file_icon_get_file (icon);
 	filename = g_file_get_path (file);
 	pixbuf = gdk_pixbuf_new_from_file_at_size (filename, size, -1, NULL);
 	g_free (filename);
 	g_object_unref (file);
-	
+
 	return pixbuf;
 }
 
@@ -793,7 +793,7 @@ show_help_dialog (GtkWindow  *parent,
 }
 
 
-GtkBuilder * 
+GtkBuilder *
 _gtk_builder_new_from_file (const char *ui_file)
 {
 	char       *filename;
@@ -807,12 +807,12 @@ _gtk_builder_new_from_file (const char *ui_file)
                 g_clear_error (&error);
         }
 	g_free (filename);
-	        
+
         return builder;
 }
 
 
-GtkWidget * 
+GtkWidget *
 _gtk_builder_get_widget (GtkBuilder *builder,
 			 const char *name)
 {
